@@ -2,6 +2,7 @@ import os
 import json
 import pymongo
 import logging
+import math
 from datetime import datetime
 from .parameter import Parameter
 from .tools import handle_date
@@ -115,12 +116,12 @@ class DBConnect():
         find_data = self.mongo_collection.find(find_dict)
         records_filtered = find_data.count()
         if not records_filtered:
-            dict_data = {
+            return {
                 'records_total': 0,
                 'records_filtered': 0,
                 'query_result': [],
+                'total_pages': 0,
             }
-            abort(Response(dict_data, 204, {}))
         if sort_list:
             find_data.sort(sort_list).limit(
                 page_size).skip(page_size*current)
@@ -135,4 +136,5 @@ class DBConnect():
             'records_total': self.mongo_collection.estimated_document_count(),
             'records_filtered': records_filtered,
             'query_result': query_result,
+            'total_pages': math.ceil(records_filtered/page_size),
         }
